package net.kldp.cats.ui;
import java.awt.geom.AffineTransform;
import java.awt.image.BufferedImage;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.Rectangle;

import javax.swing.JPanel;


public class DisplayPanel extends JPanel {
  protected BufferedImage source;
  protected int originX;
  protected int originY;
  protected double ratio;
  
  public DisplayPanel() {
    super();
    setLayout(null);
    source = null;
    originX = originY = 0;
    ratio = 1.0;
  }
  
  public DisplayPanel(BufferedImage image) throws IllegalArgumentException {
    super();
    if (null == image) {
      throw new IllegalArgumentException();
    }
    setLayout(null);
    source = image;
    originX = originY = 0;
    ratio = 1.0;
  }
  
  public void set(BufferedImage image) {
    source = image;

    if (null == source) {
      setPreferredSize(new Dimension(100, 100));
    } else {
      setPreferredSize(new Dimension((int)(ratio * source.getWidth()),
          (int) (ratio * source.getHeight())));
    }
    revalidate();
    repaint();
  }
  
  public void set(BufferedImage image, int x, int y) {
    originX = x;
    originY = y;
    set(image);
  }
  
  public void setOrigin(int x, int y) {
    originX = x;
    originY = y;
  }
  
  public void scale(int percent) {
    ratio = ((double)percent) / 100.0;
    if (null == source) {
      setPreferredSize(new Dimension(100, 100));
    } else {
      setPreferredSize(new Dimension((int)(ratio * source.getWidth()),
          (int) (ratio * source.getHeight())));
    }
    revalidate();
    repaint();
  }
  
  public void paintComponent(Graphics g) {
    Graphics2D g2 = (Graphics2D) g;
    g2.clearRect(0, 0, getWidth(), getHeight());
    if (null == source) {
      
    } else {
      AffineTransform saveXform = g2.getTransform();
      AffineTransform at = new AffineTransform();
      Rectangle r = getBounds();
      at.translate(originX + (r.width - (int)(ratio * source.getWidth()))/2,
          originY + (r.height - (int)(ratio * source.getHeight()))/2);
      at.scale(ratio, ratio);
      g2.transform(at);
      g2.drawImage(source,null,originX,originY);
      g2.setTransform(saveXform);
    }
  }
}
